<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 02/12/2004 *
 * ===================                          Last change: 11/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-theme_import.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Import of new themes                             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Importieren von neuen Themes                     *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addMenuDescription('admin', __FILE__);

if (!isExtensionActive('theme')) {
	loadTemplate('admin_settings_saved', false, generateExtensionInactiveNotInstalledMessage('theme'));
	return;
} // END - if

// Switch to testing mode
$GLOBALS['theme_mode'] = 'test';

// Import selected theme if not present
if (isPostRequestParameterSet('theme')) {
	// Check if theme is there
	if (!ifThemeExists(postRequestParameter('theme'))) {
		// Import theme
		$inc = sprintf("theme/%s/theme.php", SQL_ESCAPE(postRequestParameter('theme')));

		// Is the theme readable?
		if (isIncludeReadable($inc)) {
			// Load the theme header file
			loadInclude($inc);

			// Register it ith the exchange
			SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_themes` (`theme_path`,`theme_active`,`theme_ver`,`theme_name`)
VALUES ('%s','N','%s','%s')",
				array(
					postRequestParameter('theme'),
					$GLOBALS['theme_data']['version'],
					$GLOBALS['theme_data']['name']
				), __FILE__, __LINE__);

			// Destroy cache
			rebuildCache('themes', 'them');

			// Prepare message
			$message = getMaskedMessage('ADMIN_THEME_IMPORTED', postRequestParameter('theme'));
		} else {
			// Include file not found!
			$message = getMaskedMessage('ADMIN_THEME_INC_404', postRequestParameter('theme'));
		}
	} else {
		// Theme already imported
		$message = getMaskedMessage('ADMIN_THEME_ALREADY_INSTALLED', postRequestParameter('theme'));
	}

	// Output message
	loadTemplate('admin_settings_saved', false, $message);
} // END - if

// Initialize array
$THEMES = array(
	'theme_unix'   => array(), // Unix name from filesystem
	'theme_name'   => array(), // Title
	'theme_author' => array(), // Theme author's name
	'theme_email'  => array(), // Author's email address
	'theme_url'    => array(), // URL were you can download it from
	'theme_version'    => array(), // Version number of theme
);

// Read directory "themes"
$includes = getArrayFromDirectory('theme/', '', false, true, array('css', 'images'));

// Walk through all entries and add it
foreach ($includes as $inc) {
	// Get directory from it
	$dir = basename(dirname($inc));

	// Load include file
	loadInclude($inc);

	// Add found theme to array
	$THEMES['theme_unix'][]   = $dir;
	$THEMES['theme_name'][]   = $GLOBALS['theme_data']['name'];
	$THEMES['theme_author'][] = $GLOBALS['theme_data']['author'];
	$THEMES['theme_email'][]  = $GLOBALS['theme_data']['email'];
	$THEMES['theme_url'][]    = $GLOBALS['theme_data']['url'];
	$THEMES['theme_version'][]    = $GLOBALS['theme_data']['version'];
} // END - while

// Sort array by Uni* name
array_pk_sort($THEMES, array('theme_name'));

// Generate output lines for the template
$OUT = ''; $SW = 2;
foreach ($THEMES['theme_unix'] as $key => $unix) {
	// Already installed is default
	$formContent = '<div class="admin_note">' . getMaskedMessage('ADMIN_THEME_ALREADY_INSTALLED', $unix) . '</div>';

	// Check if current theme is already imported or not
	if (!ifThemeExists($unix)) {
		// Theme not installed
		$formContent = loadTemplate('admin_theme_import_form', true, $unix);
	} // END - if

	// Prepare content
	$content = array(
		'sw'            => $SW,
		'unix'          => $unix,
		'theme_name'    => $THEMES['theme_name'][$key],
		'theme_email'   => $THEMES['theme_email'][$key],
		'theme_author'  => $THEMES['theme_author'][$key],
		'theme_url'     => $THEMES['theme_url'][$key],
		'theme_version' => $THEMES['theme_version'][$key],
		'form_content'  => $formContent
	);

	// Add row template
	$OUT .= loadTemplate('admin_theme_import_row', true, $content);

	// Switch color
	$SW = 3 - $SW;
} // END - foreach

if (empty($OUT)) {
	// No themes found???
	$OUT .= loadTemplate('admin_theme_import_none', true, loadTemplate('admin_settings_saved', true, '{--ADMIN_NO_THEMES_FOUND--}'));
} // END - if

// Load template
loadTemplate('admin_theme_import', false, $OUT);

// [EOF]
?>
